# Config file for the libemos package
# Defines the following variables:
#
#  LIBEMOS_INCLUDE_DIRS - include directories
#  LIBEMOS_DEFINITIONS  - preprocessor definitions
#  LIBEMOS_LIBRARIES    - libraries to link against
#  LIBEMOS_FEATURES     - list of enabled features
#  LIBEMOS_VERSION      - version of the package
#
# Also defines libemos third-party library dependencies:
#  LIBEMOS_TPLS             - package names of  third-party library dependencies
#  LIBEMOS_TPL_INCLUDE_DIRS - include directories
#  LIBEMOS_TPL_DEFINITIONS  - preprocessor definitions
#  LIBEMOS_TPL_LIBRARIES    - libraries to link against

### compute paths

get_filename_component(LIBEMOS_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

set( LIBEMOS_SELF_INCLUDE_DIRS "${LIBEMOS_CMAKE_DIR}/../../../include" )
set( LIBEMOS_SELF_DEFINITIONS  "INTERPOL_TABLES_PATH="/usr/share/libemos/tables";gfortran;linux;FOPEN64;REAL_8;REAL_BIGGER_THAN_INTEGER;POINTER_64;_LARGEFILE64_SOURCE;_FILE_OFFSET_BITS=64;LITTLE_ENDIAN;INTEGER_IS_INT" )
set( LIBEMOS_SELF_LIBRARIES    "emos" )

set( LIBEMOS_TPLS              "grib_api" )
set( LIBEMOS_TPL_INCLUDE_DIRS  "/usr/include;/usr/include;/usr/include;/usr/include" )
set( LIBEMOS_TPL_DEFINITIONS   "" )
set( LIBEMOS_TPL_LIBRARIES     "/usr/lib/libgrib_api.so;/usr/lib/libgrib_api_f90.so;/usr/lib/libgrib_api_f77.so;/usr/lib/arm-linux-gnueabihf/libopenjpeg.so;/usr/lib/arm-linux-gnueabihf/libpng.so;/usr/lib/arm-linux-gnueabihf/libz.so" )

### export include paths as absolute paths

set( LIBEMOS_INCLUDE_DIRS "" )
foreach( path ${LIBEMOS_SELF_INCLUDE_DIRS} )
	get_filename_component( abspath ${path} ABSOLUTE )
	list( APPEND LIBEMOS_INCLUDE_DIRS ${abspath} )
endforeach()
list( APPEND LIBEMOS_INCLUDE_DIRS ${LIBEMOS_TPL_INCLUDE_DIRS} )

### export definitions

set( LIBEMOS_DEFINITIONS      ${LIBEMOS_SELF_DEFINITIONS} ${LIBEMOS_TPL_DEFINITIONS} )

### export list of all libraries

set( LIBEMOS_LIBRARIES        ${LIBEMOS_SELF_LIBRARIES}   ${LIBEMOS_TPL_LIBRARIES}   )

### export the features provided by the package

set( LIBEMOS_FEATURES    "TESTS;INSTALL_TABLES;INSTALL_TOOLS;FORTRAN90;SINGLE_PRECISION" )
foreach( _f ${LIBEMOS_FEATURES} )
	set( LIBEMOS_HAVE_${_f} 1 )
endforeach()

if( EXISTS ${LIBEMOS_CMAKE_DIR}/libemos-import.cmake )
  set( LIBEMOS_IMPORT_FILE "${LIBEMOS_CMAKE_DIR}/libemos-import.cmake" )
  include( ${LIBEMOS_IMPORT_FILE} )
endif()

# insert definitions for IMPORTED targets

if( NOT libemos_BINARY_DIR )

	set( IS_BUILD_DIR_EXPORT OFF )

	if( IS_BUILD_DIR_EXPORT )
		include( "/build/emoslib-gXdjkq/emoslib-4.0.7/obj-arm-linux-gnueabihf/libemos-targets.cmake" OPTIONAL )
	else()
		include( "${LIBEMOS_CMAKE_DIR}/libemos-targets.cmake" )
	endif()

endif()

# here goes the imports of the TPL's

include( ${CMAKE_CURRENT_LIST_FILE}.tpls OPTIONAL )

# publish this file as imported

set( LIBEMOS_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE} )
mark_as_advanced( LIBEMOS_IMPORT_FILE )

# set libemos_BASE_DIR for final installations or build directories

if( NOT libemos )
	if( OFF )
		set( libemos_BASE_DIR /build/emoslib-gXdjkq/emoslib-4.0.7/obj-arm-linux-gnueabihf )
	else()
		set( libemos_BASE_DIR /usr )
	endif()
endif()
